@@ -383,7 +383,7 @@ class LoggedOut(Div):
 
 @template('crudlfap/detail.html', App)
 class ObjectDetail(Div):
-    def to_html(self, **context):
+    def to_html(self, *content, **context):
         table = MDCDataTable()
         table.thead.attrs.style.display = 'none'
         table.table.attrs.style.width = '100%'
@@ -395,7 +395,12 @@ class ObjectDetail(Div):
                 MDCDataTableTd(field['value']),
             ))
 
-        return super().to_html(PageMenu(), NarrowCard(table), **context)
+        return super().to_html(
+            PageMenu(),
+            *content,
+            NarrowCard(table),
+            **context
+        )
 
     def context(self, *content, **context):
         context['page-menu'] = context['view'].router.get_menu(
@@ -447,7 +452,7 @@ class ObjectList(Div):
         )
         return super().context(*content, **context)
 
-    def to_html(self, **context):
+    def to_html(self, *content, **context):
         checkbox = None
         context['listactions'] = context['view'].router.get_menu(
             'list_action',
@@ -486,6 +491,7 @@ class ObjectList(Div):
         table.addchild(self.pagination_component(**context))
 
         return super().to_html(
+            *content,
             self.drawer_component(**context) or '',
             PageMenu(_next=context['view'].request.path),
             Div(
