@@ -75,7 +75,7 @@ class DeleteMixin(ActionMixin):
         return super().form_valid()
 
     def get_success_url(self):
-        return self.router['list'].reverse()
+        return self.request.GET.get('_next', self.router['list'].reverse())
 
 
 class DetailMixin:
