@@ -1,22 +1,28 @@
 from crudlfap.settings import *  # noqa
 
+BASE_DIR = Path(__file__).resolve().parent.parent
+
 INSTALLED_APPS += [  # noqa
+    # CRUDLFA+ extras
+    'django_registration',
+    'crudlfap_registration',
+
     # CRUDLFA+ examples
     'crudlfap_example.artist',
     'crudlfap_example.song',
     'crudlfap_example.blog',
-
-    # CRUDLFA+ extras
-    'django_registration',
-    'crudlfap_registration',
 ]
 
-ROOT_URLCONF = 'crudlfap_example.urls'
+ROOT_URLCONF = os.path.dirname(__file__).split('/')[-1] + '.urls'
 
 DATABASES = {
     'default': {
         'ENGINE': os.getenv('DB_ENGINE', 'django.db.backends.sqlite3'),
-        'NAME': os.getenv('DB_NAME', os.path.join(BASE_DIR, 'db.sqlite3')),
+        'NAME': os.getenv('DB_NAME', os.path.join(
+            os.path.dirname(__file__),
+            '..',
+            'db.sqlite3',
+        )),
         'HOST': os.getenv('DB_HOST'),
         'USER': os.getenv('DB_USER'),
         'PASSWORD': os.getenv('DB_PASS'),
